@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '1.004001';
+$MetaCPAN::Client::VERSION = '1.005000';
 use Moo;
 use Carp;
 
@@ -12,6 +12,7 @@ use MetaCPAN::Client::Distribution;
 use MetaCPAN::Client::Module;
 use MetaCPAN::Client::File;
 use MetaCPAN::Client::Favorite;
+use MetaCPAN::Client::Pod;
 use MetaCPAN::Client::Rating;
 use MetaCPAN::Client::Release;
 use MetaCPAN::Client::ResultSet;
@@ -69,6 +70,13 @@ sub file {
     return $self->_get( 'file', $path );
 }
 
+sub pod {
+    my $self = shift;
+    my $name = shift;
+
+    return MetaCPAN::Client::Pod->new({ name => $name });
+}
+
 #
 # $api->rating({ dist => "Moose" })
 #   is equal to http://api.metacpan.org/v0/favorite/_search?q=distribution:Moose
@@ -234,7 +242,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 1.004001
+version 1.005000
 
 =head1 SYNOPSIS
 
@@ -296,7 +304,7 @@ under C<SEARCH SPEC>.
 
 Return a L<MetaCPAN::Client::Author> object on a simple search (PAUSE ID), or
 a L<MetaCPAN::Client::ResultSet> object propagated with
-L<MetaCPAN::Client::Author> objects on a complex (search spec based) search.
+L<MetaCPAN::Client::Author> objects on a complex (L<search spec based|/"SEARCH SPEC">) search.
 
 =head2 module
 
@@ -309,7 +317,7 @@ under C<SEARCH SPEC>.
 
 Return a L<MetaCPAN::Client::Module> object on a simple search (module name), or
 a L<MetaCPAN::Client::ResultSet> object propagated with
-L<MetaCPAN::Client::Module> objects on a complex (search spec based) search.
+L<MetaCPAN::Client::Module> objects on a complex (L<search spec based|/"SEARCH SPEC">) search.
 
 =head2 distribution
 
@@ -322,7 +330,7 @@ explained below under C<SEARCH SPEC>.
 
 Return a L<MetaCPAN::Client::Distribution> object on a simple search
 (distribution name), or a L<MetaCPAN::Client::ResultSet> object propagated with
-L<MetaCPAN::Client::Distribution> objects on a complex (search spec based)
+L<MetaCPAN::Client::Distribution> objects on a complex (L<search spec based|/"SEARCH SPEC">)
 search.
 
 =head2 file
@@ -348,7 +356,7 @@ below under C<SEARCH SPEC>.
 
 Return a L<MetaCPAN::Client::Release> object on a simple search (release name),
 or a L<MetaCPAN::Client::ResultSet> object propagated with
-L<MetaCPAN::Client::Release> objects on a complex (search spec based) search.
+L<MetaCPAN::Client::Release> objects on a complex (L<search spec based|/"SEARCH SPEC">) search.
 
 =head2 reverse_dependencies
 
@@ -374,9 +382,7 @@ Internal construction wrapper. Do not use.
 The hash-based search spec is common to many searches. It is quite
 feature-rich and allows to disambiguate different types of searches.
 
-=head2 Simple
-
-Simple searches just contain keys and values:
+Basic search specs just contain a hash of keys and values:
 
     my $author = $mcpan->author( { name => 'Micha Nasriachi' } );
 
